==> jscommunicator-1.0.21.tgz: package/src/genericTransactionalMail.js <==
"use strict"

let base =  require('./base');
let types = require('./types');

class MailGenericTransactional extends base.Base{
  constructor(host, config, appName){
    super(host, config, appName);
  }

  sendMail(fromName, fromMail, subject, body, emailType, files,
          to, hash, referenceId, referenceType, toName="",
          cc="", bcc="", plaintext="", replyTo=null, expiryTime=null,
          createdBy=null){
    this.validateMailType(emailType.toUpperCase());
    let job = new types.GenericTransactionalMail();
    job.from_name = fromName;
    job.from_address = fromMail;
    job.to_name = toName;
    job.to_address = to;
    job.expiry_time = expiryTime;
    job.subject = subject;
    job.body = body;
    job.plaintext = plaintext;
    job.reference_id = referenceId;
    job.reference_type = referenceType;
    job.app_name = this.appName;
    job.created_by = createdBy;
    job.email_type = emailType.toUpperCase();
    job.reply_to = replyTo;
    job.hash = hash;
    job.mail_type = 'generic_transactional';

    if(referenceId !== parseInt(referenceId, 10)){
      throw "referenceId should be integer";
    }
    if(typeof(cc) == 'string' && cc.length>0){
      job.cc = [cc];
    }else{
      job.cc = cc;
    }
    if(typeof(bcc) == 'string' && bcc.length>0){
      job.bcc = [bcc];
    }else{
      job.bcc = bcc;
    }

    let attachments = [];
    if(files){
      for(let i=0;i<files.length;i++){
        let att = new types.Attachment();
        att.name = files[i];
        att.location = files[files[i]];
        attachments.push(att);
      }
    }
    job.attachments = attachments;
    this.send(job, this.queueNames.sendGenericTransactionalMailQueue, 0);
  }

  getMailCountByType(mailType, startDate, endDate, deliveryStatus, callback){
    let data = {};
    data.start_date = startDate;
    data.end_date = endDate;
    data.mail_type = mailType;
    data.delivery_status = deliveryStatus;
    const response = this.get('/generictransactionalmail/get_mail_count_for_type', data, (err, response)=>{
      if(err){
        callback(err);
      }
      else{
        callback(null, response);
      }
    });
  }

  validateMailType(type){
    const allowedTypes = [
      'FABRIC_ROI_REPORT',
      'FABRIC_RENEWAL_ALERT',
      'MERGE_ACCOUNTS_NOTIFICATION',
      'MERGE_FAILED',
      'VN_DETAILS',
      'ALERT_BAD_HEALTH',
      'FABRIC_DQS_REPORT',
      'SURVEY_VERIFICATION_EMAIL',
      'FIT_GENERIC_MAIL',
      'FIT_EDITOR_FEEDBACK_MAIL',
      'CONSULT_GENERIC_MAIL',
      'REACH_TOS_MAIL',
      'REACH_QUALITY_REMINDER',
      'QIKWELL_APPOINTMENT_REMINDER_MAIL',
      'FEEDBACK_DAILY_HEALTH_EMAIL',
      'FEEDBACK_SURVEY_EMAIL',
      'TAB_BIAS_DAILY_REPORT',
      'TAB_BIAS_DETECTION_EMAIL',
      'SCOUT_HOURLY_MAIL',
      'PHARMA_MAIL',
      'RAY_REPORT_APPOINTMENTS',
      'RAY_REPORT_APPOINTMENTS_SUMMARY',
      'RAY_REPORT_DAILY_SUMMARY',
      'RAY_REPORT_EXPENSE',
      'RAY_REPORT_EXPENSE_SUMMARY',
      'RAY_REPORT_INVOICE',
      'RAY_REPORT_INVOICE_SUMMARY',
      'RAY_REPORT_PATIENTS',
      'RAY_REPORT_PATIENTS_SUMMARY',
      'RAY_REPORT_PAYMENT',
      'RAY_REPORT_PAYMENTS_SUMMARY',
      'RAY_REPORT_PAYMENT_DETAILS_SUMMARY',
      'RAY_REPORT_TREATMENTS',
      'RAY_REPORT_TREATMENTS_SUMMARY',
      'DOCTOR_NO_SHOW',
      'REACH_DAILY_ROI_EMAIL',
      'FABRIC_BLUEBOOK_MAIL',
      'STORE_SELF_RENEWAL',
      'STORE_REFERRAL_EMAILS',
      'STORE_KEY_ACCOUNT_GROUP',
      'DX_ORDER_CREATED_LAB',
      'DX_ORDER_CREATED_CUSTOMER',
      'DX_ORDER_CREATED_OPS',
      'DX_ORDER_RESCHEDULE_LAB',
      'DX_REPORT_SHARED',
      'DX_ORDER_CANCELLED_EDIT_LAB',
      'DX_ORDER_CANCELLED_EDIT_CUSTOMER',
      'DX_ORDER_CANCELLED_EDIT_OPS',
      'DX_ORDER_CANCELLED_LAB',
      'DX_ORDER_CANCELLED_CUSTOMER',
      'DX_ORDER_CANCELLED_OPS',
      'DX_ONBOARDING_DOS_GENERATION',
      'DX_ONBOARDING_DOS_REVIEW',
      'SOS'
    ];

    if(allowedTypes.indexOf(type) < 0){
      throw "Invalid mail type";
    }
  }
}

module.exports = {
  MailGenericTransactional: MailGenericTransactional
}

==> jscommunicator-1.0.27.tgz: package/src/genericTransactionalMail.js <==
"use strict"

let base =  require('./base');
let types = require('./types');

class MailGenericTransactional extends base.Base{
  constructor(request, config, appName){
    super(request, config, appName);
  }

  sendMail(fromName, fromMail, subject, body, emailType, files,
          to, hash, referenceId, referenceType, toName="",
          cc="", bcc="", plaintext="", replyTo=null, expiryTime=null,
          createdBy=null){
    this.validateMailType(emailType.toUpperCase());
    let job = new types.GenericTransactionalMail();
    job.from_name = fromName;
    job.from_address = fromMail;
    job.to_name = toName;
    job.to_address = to;
    job.expiry_time = expiryTime;
    job.subject = subject;
    job.body = body;
    job.plaintext = plaintext;
    job.reference_id = referenceId;
    job.reference_type = referenceType;
    job.app_name = this.appName;
    job.created_by = createdBy;
    job.email_type = emailType.toUpperCase();
    job.reply_to = replyTo;
    job.hash = hash;
    job.mail_type = 'generic_transactional';

    if(referenceId !== parseInt(referenceId, 10)){
      throw "referenceId should be integer";
    }
    if(typeof(cc) == 'string' && cc.length>0){
      job.cc = [cc];
    }else{
      job.cc = cc;
    }
    if(typeof(bcc) == 'string' && bcc.length>0){
      job.bcc = [bcc];
    }else{
      job.bcc = bcc;
    }

    let attachments = [];
    if(files){
      for(let i=0;i<files.length;i++){
        let att = new types.Attachment();
        att.name = files[i];
        att.location = files[files[i]];
        attachments.push(att);
      }
    }
    job.attachments = attachments;
    this.send(job, this.queueNames.sendGenericTransactionalMailQueue, 0);
  }

  getMailCountByType(mailType, startDate, endDate, deliveryStatus, callback){
    let data = {};
    data.start_date = startDate;
    data.end_date = endDate;
    data.mail_type = mailType;
    data.delivery_status = deliveryStatus;
    const response = this.get('/generictransactionalmail/get_mail_count_for_type', data, (err, response)=>{
      if(err){
        callback(err);
      }
      else{
        callback(null, response);
      }
    });
  }

  validateMailType(type){
    const allowedTypes = [
      'FABRIC_ROI_REPORT',
      'FABRIC_RENEWAL_ALERT',
      'MERGE_ACCOUNTS_NOTIFICATION',
      'MERGE_FAILED',
      'VN_DETAILS',
      'ALERT_BAD_HEALTH',
      'FABRIC_DQS_REPORT',
      'SURVEY_VERIFICATION_EMAIL',
      'FIT_GENERIC_MAIL',
      'FIT_EDITOR_FEEDBACK_MAIL',
      'CONSULT_GENERIC_MAIL',
      'REACH_TOS_MAIL',
      'REACH_QUALITY_REMINDER',
      'QIKWELL_APPOINTMENT_REMINDER_MAIL',
      'FEEDBACK_DAILY_HEALTH_EMAIL',
      'FEEDBACK_SURVEY_EMAIL',
      'TAB_BIAS_DAILY_REPORT',
      'TAB_BIAS_DETECTION_EMAIL',
      'SCOUT_HOURLY_MAIL',
      'PHARMA_MAIL',
      'RAY_REPORT_APPOINTMENTS',
      'RAY_REPORT_APPOINTMENTS_SUMMARY',
      'RAY_REPORT_DAILY_SUMMARY',
      'RAY_REPORT_EXPENSE',
      'RAY_REPORT_EXPENSE_SUMMARY',
      'RAY_REPORT_INVOICE',
      'RAY_REPORT_INVOICE_SUMMARY',
      'RAY_REPORT_PATIENTS',
      'RAY_REPORT_PATIENTS_SUMMARY',
      'RAY_REPORT_PAYMENT',
      'RAY_REPORT_PAYMENTS_SUMMARY',
      'RAY_REPORT_PAYMENT_DETAILS_SUMMARY',
      'RAY_REPORT_TREATMENTS',
      'RAY_REPORT_TREATMENTS_SUMMARY',
      'DOCTOR_NO_SHOW',
      'REACH_DAILY_ROI_EMAIL',
      'FABRIC_BLUEBOOK_MAIL',
      'STORE_SELF_RENEWAL',
      'STORE_REFERRAL_EMAILS',
      'STORE_KEY_ACCOUNT_GROUP',
      'DX_ORDER_CREATED_LAB',
      'DX_ORDER_CREATED_CUSTOMER',
      'DX_ORDER_CREATED_OPS',
      'DX_ORDER_RESCHEDULE_LAB',
      'DX_REPORT_SHARED',
      'DX_ORDER_CANCELLED_EDIT_LAB',
      'DX_ORDER_CANCELLED_EDIT_CUSTOMER',
      'DX_ORDER_CANCELLED_EDIT_OPS',
      'DX_ORDER_CANCELLED_LAB',
      'DX_ORDER_CANCELLED_CUSTOMER',
      'DX_ORDER_CANCELLED_OPS',
      'DX_ONBOARDING_DOS_GENERATION',
      'DX_ONBOARDING_DOS_REVIEW',
      'SOS'
    ];

    if(allowedTypes.indexOf(type) < 0){
      throw "Invalid mail type";
    }
  }
}

module.exports = {
  MailGenericTransactional: MailGenericTransactional
}
